==> haskell-pandoc-server-0.1.0.5-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-CkQewDQJvM4JIBJg2bHZ6N
key:                  pandoc-server-0.1.0.5-CkQewDQJvM4JIBJg2bHZ6N
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  3ad8cd51098f86ced1b39547dd22f11b
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-CkQewDQJvM4JIBJg2bHZ6N
depends:
    aeson-2.1.2.1-HPwo2VO3hzcFr4fiGB5Oro base-4.17.2.1
    base64-bytestring-1.2.1.0-LY9UF0mrytX7ReHq71Oo2M
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
    doctemplates-0.11.0.1-YrcAc7RuQYFHI3miwHZp
    pandoc-3.1.12.2-JFqy3fTVsSa30ehJUpL5fc
    pandoc-types-1.23.1-4YkLm5YX8y1r21ygclrwk
    servant-server-0.20.2-DIQksh04bGn4ZjBpO5ETY0
    skylighting-0.14.1.1-HPLrfXxSgoL9pWesSxXd4H text-2.0.2
    unicode-collation-0.1.3.6-1Vs49gQu4N6K1AkspfPlhJ
    wai-3.2.4-9jkCTz3VUjM6XVKXhFmJSz
    wai-cors-0.2.7-YKVE0yPHyG93MIobr9pRC

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-server-0.1.0.5-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-4FDWhcLYos0C3tOWJ54MCu
key:                  pandoc-server-0.1.0.5-4FDWhcLYos0C3tOWJ54MCu
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  ac5bba0ec219c3e84d6f7f6bd816c2bc
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-4FDWhcLYos0C3tOWJ54MCu
depends:
    aeson-2.1.2.1-8gRdOgbBkF57DAEniCzHis base-4.17.2.1
    base64-bytestring-1.2.1.0-IbCUnYF5PxIJ57HxqijudZ
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-8zpNuXeugnsCXhsU9L7wsy
    doctemplates-0.11.0.1-EP2LbaQEWGYAbUrva4mwrR
    pandoc-3.1.12.2-FEvMmhun21IC9l21bZhc86
    pandoc-types-1.23.1-BumdqhotWU53CYJOFFMW2R
    servant-server-0.20.2-FJBPb1Nu8eD4gowZNCCVvJ
    skylighting-0.14.1.1-DU9Uvdr07lP9tO0Q8cNnf5 text-2.0.2
    unicode-collation-0.1.3.6-39hXhGtzD7Q5c3GZhAqao4
    wai-3.2.4-EhNMiHqwqcPHb2wBYuWApz
    wai-cors-0.2.7-5BNiGbnX2rv9Yzon3ik0lS

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
